/*
 * cron4j - A pure Java cron-like scheduler
 * 
 * Copyright (C) 2007-2009 Carlo Pelliccia (www.sauronsoftware.it)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License, version 2.1,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package it.sauronsoftware.cron4j;

/**
 * <p>
 * A scheduling patterns validator.
 * </p>
 * 
 * <p>
 * The class lets you validate a scheduling pattern before/without sending it to
 * the schedule()/reschedule() method of a Scheduler instance. Simply call:
 * </p>
 * 
 * <pre>
 * boolean valid = SchedulingPatternValidator.validate(thePattern);
 * </pre>
 * 
 * <p>
 * It is useful in validating user-entered patterns.
 * </p>
 * 
 * @author Carlo Pelliccia
 */
public class SchedulingPatternValidator {

	/**
	 * This method validate a scheduling pattern string.
	 * 
	 * @param schedulingPattern
	 *            The pattern.
	 * @return true if the pattern is valid. It means that it could be used in
	 *         the scheduling of task, calling the schedule() method of a
	 *         Scheduler object, without any trouble: if the pattern is valid no
	 *         InvalidPatternException could be thrown.
	 */
	public static boolean validate(String schedulingPattern) {
		try {
			new SchedulingPattern(schedulingPattern);
		} catch (InvalidPatternException e) {
			return false;
		}
		return true;
	}

}
