/*
 * cron4j - A pure Java cron-like scheduler
 * 
 * Copyright (C) 2007-2009 Carlo Pelliccia (www.sauronsoftware.it)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License, version 2.1,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package it.sauronsoftware.cron4j;

/**
 * This class extends Thread in the purpose of give notice to the scheduler when
 * a thread is completed.
 * 
 * @author Carlo Pelliccia
 * 
 */
class WatchedThread extends Thread {

	/**
	 * The scheduler that has spawned this thread.
	 */
	private Scheduler scheduler;

	/**
	 * Builds the thread.
	 * 
	 * @param scheduler
	 *            The scheduler spawning the thread.
	 * @param task
	 *            The task whose Runnable object that must be started in the
	 *            thread.
	 */
	public WatchedThread(Scheduler scheduler, Task task) {
		super(task.getRunnable(), "cron4j-task-" + task.getId());
		this.scheduler = scheduler;
	}

	public void run() {
		// Catch unwanted exceptions.
		try {
			super.run();
		} catch (RuntimeException t) {
			throw t;
		} catch (Error t) {
			throw t;
		} finally {
			// Notify the scheduler.
			scheduler.notifyWatchedThreadExiting(this);
		}
	}

}
